pub struct ZwpTabletV1 { /* private fields */ }Expand description
graphics tablet device
The wp_tablet interface represents one graphics tablet device. The tablet interface itself does not generate events; all events are generated by wp_tablet_tool objects when in proximity above a tablet.
A tablet has a number of static characteristics, e.g. device name and pid/vid. These capabilities are sent in an event sequence after the wp_tablet_seat.tablet_added event. This initial event sequence is terminated by a wp_tablet.done event.
See also the Request enum for this interface.
Implementations
Sourceimpl ZwpTabletV1
impl ZwpTabletV1
Sourcepub fn name(&self, name: String)
pub fn name(&self, name: String)
tablet device name
This event is sent in the initial burst of events before the wp_tablet.done event.
Sourcepub fn id(&self, vid: u32, pid: u32)
pub fn id(&self, vid: u32, pid: u32)
tablet device USB vendor/product id
This event is sent in the initial burst of events before the wp_tablet.done event.
Sourcepub fn path(&self, path: String)
pub fn path(&self, path: String)
path to the device
A system-specific device path that indicates which device is behind this wp_tablet. This information may be used to gather additional information about the device, e.g. through libwacom.
A device may have more than one device path. If so, multiple wp_tablet.path events are sent. A device may be emulated and not have a device path, and in that case this event will not be sent.
The format of the path is unspecified, it may be a device node, a sysfs path, or some other identifier. It is up to the client to identify the string provided.
This event is sent in the initial burst of events before the wp_tablet.done event.